@@ -28,6 +28,28 @@ async def peet_timing(username: str, session: RequestManager):
     return 0
         
 
+async def star_shopping_timing(username: str, session: RequestManager):
+    
+    resp, _, resp_json = await session.get(
+        f"https://api.star.shopping/droptime/{username}",
+        headers={"User-Agent": "Sniper"}
+    )
+
+    if resp.status < 300:
+        log.info(
+            f"sniping {color.cyan}{username}{color.reset} @ {datetime.fromtimestamp(resp_json['unix'])}"
+        )
+        return resp_json["unix"]
+    
+    log.error(
+        f"failed to parse droptime for {color.l_cyan}{username}{color.reset} through star.shopping"
+    )
+
+    log.error(f"{resp.text} | {resp.status}")
+
+    close(0)
+    return 0
+
 async def namemc_timing(username: str, session: RequestManager) -> float:
     resp, text, _ = await session.get(f"https://namemc.com/search?q={username}")
 
@@ -128,7 +150,7 @@ async def coolkidmacho_timing(
     log.error(
         f"failed to parse droptime for {color.l_cyan}{username}{color.reset} through Coolkidmacho's droptime API"
     )
-    log.error(f"{resp_json['error']} | {resp.status}")
+    log.error(f"{resp.text} | {resp.status}")
 
     close(0)
     return 0
